=== modified file 'configure.ac'
--- configure.ac	2013-02-01 00:51:16 +0000
+++ configure.ac	2019-03-12 15:10:45 +0000
@@ -13,7 +13,7 @@
 GNOME_COMMON_INIT
 GLIB_GSETTINGS
 
-pkg_modules="glib-2.0 >= 2.34 gtk+-3.0 libnotify gio-2.0 >= 2.26 x11"
+pkg_modules="glib-2.0 >= 2.34 gtk+-3.0 libnotify gio-2.0 >= 2.26 x11 json-glib-1.0"
 
 PKG_CHECK_EXISTS(gudev-1.0, [ HAVE_GUDEV=1 ])
 if test "x$HAVE_GUDEV" != "x"; then

=== modified file 'data/com.ubuntu.update-notifier.gschema.xml.in'
--- data/com.ubuntu.update-notifier.gschema.xml.in	2013-06-05 17:31:47 +0000
+++ data/com.ubuntu.update-notifier.gschema.xml.in	2019-03-12 15:10:45 +0000
@@ -25,5 +25,10 @@
       <summary>Time of last release check</summary>
       <description>The last time update-notifier checked for a new release.  The format is seconds since UNIX epoch.</description>
     </key>
+    <key name="show-livepatch-status-icon" type="b">
+      <default>true</default>
+      <summary>Show Livepatch status icon</summary>
+      <description>Enable or diable the Livepatch status icon in the systray.</description>
+    </key>
   </schema>
 </schemalist>

=== modified file 'debian/control'
--- debian/control	2019-02-16 16:07:56 +0000
+++ debian/control	2019-03-12 15:10:45 +0000
@@ -6,6 +6,7 @@
                dh-python,
                libgtk-3-dev,
                libglib2.0-dev (>= 2.34),
+               libjson-glib-dev,
                intltool,
                libnotify-dev (>= 0.7),
                libgudev-1.0-dev,

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2017-08-21 17:30:53 +0000
+++ po/POTFILES.in	2019-03-12 15:10:45 +0000
@@ -11,6 +11,7 @@
 src/cdroms.c
 src/hooks.c
 src/livepatch.c
+src/livepatch-tray.c
 src/update.c
 src/update-notifier.c
 [type: gettext/glade]ui/hooks-dialog.ui

=== modified file 'src/Makefile.am'
--- src/Makefile.am	2018-04-20 18:02:03 +0000
+++ src/Makefile.am	2019-03-12 15:10:45 +0000
@@ -23,6 +23,10 @@
 			   hooks.c\
 			   crash.c\
 			   crash.h\
+			   livepatch-tray.c\
+			   livepatch-tray.h\
+			   livepatch-utils.c\
+			   livepatch-utils.h\
 			   update.c\
 			   update.h\
 			   release.c\

=== added file 'src/livepatch-tray.c'
--- src/livepatch-tray.c	1970-01-01 00:00:00 +0000
+++ src/livepatch-tray.c	2019-03-12 15:10:45 +0000
@@ -0,0 +1,286 @@
+/* livepatch-tray.c
+ * Copyright (C) 2019 Andrea Azzarone <andrea.azzarone@canonical.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor
+ * Boston, MA  02110-1301 USA.
+ */
+#include <gio/gdesktopappinfo.h>
+#include <glib.h>
+
+#include "update-notifier.h"
+#include "livepatch-tray.h"
+#include "livepatch-utils.h"
+#include "trayappletui.h"
+
+#define LIVEPATCH_COMMON_DIRECTORY "/var/snap/canonical-livepatch/common"
+#define LIVEPATCH_SNAP_DIRECTORY "/snap/canonical-livepatch"
+
+typedef struct _LivepatchTrayAppletPriv LivepatchTrayAppletPriv;
+struct _LivepatchTrayAppletPriv
+{
+  GtkWidget    *menuitem_enabled;
+  GtkWidget    *menuitem_desc;
+
+  GFileMonitor *common_dir_monitor;
+  GFileMonitor *snap_dir_monitor;
+
+  guint         idle_id;
+};
+
+static void
+on_settings_menuitem_activated(GObject *self, gpointer user_data)
+{
+  g_autoptr(GDesktopAppInfo) info = NULL;
+  g_autoptr(GdkAppLaunchContext) context = NULL;
+  g_autoptr(GError) error = NULL;
+
+  info = g_desktop_app_info_new(LIVEPATCH_DESKTOP_FILE);
+  if (info = NULL)
+    {
+      g_warning("Could not find application '%s'", LIVEPATCH_DESKTOP_FILE);
+      return;
+    }
+
+  context = gdk_display_get_app_launch_context(gdk_display_get_default());
+  if (!g_app_info_launch(G_APP_INFO(info), NULL,
+                         G_APP_LAUNCH_CONTEXT(context), &error))
+    {
+      g_warning("Could not launch application '%s'", LIVEPATCH_DESKTOP_FILE);
+    }
+}
+
+
+static void
+livepatch_trayicon_create_menu(TrayApplet *ta)
+{
+  LivepatchTrayAppletPriv *priv = (LivepatchTrayAppletPriv *) ta->user_data;
+  GtkWidget *menuitem;
+
+  ta->menu = gtk_menu_new();
+
+  priv->menuitem_enabled = gtk_menu_item_new();
+  gtk_widget_set_sensitive(priv->menuitem_enabled, FALSE);
+  gtk_menu_shell_append(GTK_MENU_SHELL(ta->menu), priv->menuitem_enabled);
+
+  priv->menuitem_desc = gtk_menu_item_new();
+  gtk_widget_set_sensitive(priv->menuitem_desc, FALSE);
+  gtk_menu_shell_append(GTK_MENU_SHELL(ta->menu), priv->menuitem_desc);
+
+  menuitem = gtk_separator_menu_item_new();
+  gtk_menu_shell_append(GTK_MENU_SHELL(ta->menu), menuitem);
+
+  menuitem = gtk_menu_item_new_with_label(_("Livepatch Settings…"));
+  gtk_menu_shell_append(GTK_MENU_SHELL(ta->menu), menuitem);
+  g_signal_connect(G_OBJECT(menuitem), "activate",
+                   G_CALLBACK(on_settings_menuitem_activated), ta);
+
+  gtk_widget_show_all(ta->menu);
+}
+
+static gboolean
+check_livepatch(TrayApplet *ta)
+{
+  LivepatchTrayAppletPriv *priv = (LivepatchTrayAppletPriv *) ta->user_data;
+  gboolean show_status_icon;
+  g_autofree gchar *check_state = NULL;
+  g_autofree gchar *state = NULL;
+  g_autoptr(GError) error = NULL;
+
+  show_status_icon = g_settings_get_boolean(ta->un->settings,
+                                            SETTINGS_KEY_SHOW_LIVEPATCH_ICON);
+
+  if (!show_status_icon || !livepatch_is_supported())
+    {
+      tray_applet_ui_set_visible(ta, FALSE);
+
+      priv->idle_id = 0;
+      return G_SOURCE_REMOVE;
+    }
+
+  tray_applet_ui_set_visible(ta, TRUE);
+
+  if (!livepatch_is_running())
+    {
+      tray_applet_ui_set_icon(ta, "gtk-no");
+      gtk_menu_item_set_label(GTK_MENU_ITEM(priv->menuitem_enabled),
+                              _("Livepatch is off"));
+      gtk_widget_set_visible(priv->menuitem_desc, FALSE);
+
+      priv->idle_id = 0;
+      return G_SOURCE_REMOVE;
+    }
+
+  gtk_menu_item_set_label(GTK_MENU_ITEM(priv->menuitem_enabled),
+                          _("Livepatch is on"));
+
+  check_state = livepatch_get_check_state(&error);
+  if (check_state == NULL)
+    g_warning("Cannot get Livepatch check-state: %s", error->message);
+
+  state = livepatch_get_state(&error);
+  if (state == NULL)
+    g_warning("Cannot get Livepatch state: %s", error->message);
+
+  if (!g_strcmp0(check_state, "checked") &&
+      (!g_strcmp0(state, "applied") || !g_strcmp0(state, "nothing-to-apply")))
+    {
+      gssize num_fixes;
+      g_autofree gchar *label = NULL;
+
+      tray_applet_ui_set_icon(ta, "gtk-yes");
+
+      num_fixes = livepatch_get_num_fixes(&error);
+      if (num_fixes == -1)
+        {
+          g_warning("Cannot get applied Livepatch fixes: %s", error->message);
+          num_fixes = 0;
+        }
+
+      gtk_widget_set_visible(priv->menuitem_desc, TRUE);
+
+      if (num_fixes == 0)
+        label = g_strdup(_("No current updates"));
+      else
+        label = g_strdup_printf(ngettext("%" G_GSSIZE_FORMAT " current update",
+                                         "%" G_GSSIZE_FORMAT " current updates",
+                                         num_fixes), num_fixes);
+
+        gtk_menu_item_set_label(GTK_MENU_ITEM(priv->menuitem_desc), label);
+    }
+  else if (!g_strcmp0(check_state, "needs-check") ||
+           !g_strcmp0(state, "unapplied"))
+    {
+      /* Check livepatch status again */
+      return G_SOURCE_CONTINUE;
+    }
+  else
+    {
+      tray_applet_ui_set_icon(ta, "dialog-error");
+
+      if (check_state == NULL || !g_strcmp0(check_state, "check-failed"))
+        {
+          gtk_menu_item_set_label(GTK_MENU_ITEM(priv->menuitem_desc),
+            _("An error occured when checking for Livepatch updates."));
+        }
+      else
+        {
+          gtk_menu_item_set_label(GTK_MENU_ITEM(priv->menuitem_desc),
+            _("An error occured when applying Livepatch updates."));
+        }
+    }
+
+    priv->idle_id = 0;
+    return G_SOURCE_REMOVE;
+}
+
+static void
+gsettings_visibility_changed_cb(GSettings *settings,
+                                gchar     *key,
+                                gpointer   user_data)
+{
+  TrayApplet *ta = (TrayApplet *) user_data;
+  LivepatchTrayAppletPriv *priv = (LivepatchTrayAppletPriv *) ta->user_data;
+
+  if (priv->idle_id <= 0)
+    priv->idle_id = g_idle_add((GSourceFunc) check_livepatch, ta);
+}
+
+static void
+livepatch_directory_changed_cb(GFileMonitor     *monitor,
+                               GFile            *file,
+                               GFile            *other_file,
+                               GFileMonitorEvent event_type,
+                               gpointer          user_data)
+{
+  TrayApplet *ta = (TrayApplet *) user_data;
+  LivepatchTrayAppletPriv *priv = (LivepatchTrayAppletPriv *) ta->user_data;
+
+  if (priv->idle_id <= 0)
+    priv->idle_id = g_idle_add((GSourceFunc) check_livepatch, ta);
+}
+
+void
+livepatch_tray_icon_init(TrayApplet *ta)
+{
+  g_autoptr(GFile) livepatch_common_dir = NULL;
+  g_autoptr(GFile) livepatch_snap_dir = NULL;
+  g_autoptr(GFileMonitor) common_dir_monitor = NULL;
+  g_autoptr(GFileMonitor) snap_dir_monitor = NULL;
+  g_autoptr(GError) error = NULL;
+  LivepatchTrayAppletPriv *priv;
+
+  if (!livepatch_is_supported())
+    return;
+
+  if (!livepatch_has_settings_ui())
+    {
+      g_warning("There is no graphical application installed to manage "
+                "Livepatch. The livepatch status icon will not be displayed.");
+      return;
+    }
+
+  /* Monitor the directory LIVEPATCH_COMMON_DIRECTORY for changes to update
+     the status of the indicator. */
+  livepatch_common_dir = g_file_new_for_path(LIVEPATCH_COMMON_DIRECTORY);
+  common_dir_monitor = g_file_monitor_directory(livepatch_common_dir,
+                                                G_FILE_MONITOR_NONE,
+                                                NULL, &error);
+  if (common_dir_monitor == NULL)
+    {
+        g_warning("Couldn't create directory monitor on %s. Error: %s\n",
+                  LIVEPATCH_COMMON_DIRECTORY, error->message);
+        return;
+    }
+
+  /* We also need to monitor the directory LIVEPATCH_SNAP_DIRECTORY in order to
+     detect if the snap was enabled/disabled. This consider the case
+     canonical-livepatch is enabled but the snap is disabled. */
+  livepatch_snap_dir = g_file_new_for_path(LIVEPATCH_SNAP_DIRECTORY);
+  snap_dir_monitor = g_file_monitor_directory(livepatch_snap_dir,
+                                              G_FILE_MONITOR_WATCH_MOUNTS,
+                                              NULL, &error);
+  if (snap_dir_monitor == NULL)
+    {
+        g_warning("Couldn't create directory monitor on %s. Error: %s\n",
+                  LIVEPATCH_SNAP_DIRECTORY, error->message);
+        return;
+    }
+
+  priv = g_new0(LivepatchTrayAppletPriv, 1);
+  priv->common_dir_monitor = g_steal_pointer(&common_dir_monitor);
+  priv->snap_dir_monitor = g_steal_pointer(&snap_dir_monitor);
+  ta->user_data = priv;
+
+  tray_applet_ui_ensure(ta);
+
+  /* Menu initialization */
+  livepatch_trayicon_create_menu(ta);
+  tray_applet_ui_set_menu(ta, ta->menu);
+
+  g_signal_connect(ta->un->settings,
+                   "changed::"SETTINGS_KEY_SHOW_LIVEPATCH_ICON,
+                   G_CALLBACK(gsettings_visibility_changed_cb), ta);
+  g_signal_connect(priv->common_dir_monitor,
+                   "changed",
+                   G_CALLBACK(livepatch_directory_changed_cb), ta);
+  g_signal_connect(priv->snap_dir_monitor,
+                   "changed",
+                   G_CALLBACK(livepatch_directory_changed_cb), ta);
+
+  /* We always run check_livepatch in an idle beacuse this allows us to easily
+     check again the status of livepatch if it is in a transistion state (e.g.
+     it is downloading the patches or applying them, etc.) */
+  priv->idle_id = g_idle_add((GSourceFunc) check_livepatch, ta);
+}

=== added file 'src/livepatch-tray.h'
--- src/livepatch-tray.h	1970-01-01 00:00:00 +0000
+++ src/livepatch-tray.h	2019-03-12 15:10:45 +0000
@@ -0,0 +1,22 @@
+/* livepatch-tray.h
+ * Copyright (C) 2019 Andrea Azzarone <andrea.azzarone@canonical.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor
+ * Boston, MA  02110-1301 USA.
+ */
+
+#pragma once
+
+void livepatch_tray_icon_init(TrayApplet *ta);

=== added file 'src/livepatch-utils.c'
--- src/livepatch-utils.c	1970-01-01 00:00:00 +0000
+++ src/livepatch-utils.c	2019-03-12 15:10:45 +0000
@@ -0,0 +1,212 @@
+/* livepatch-utils.c
+ * Copyright (C) 2019 Andrea Azzarone <andrea.azzarone@canonical.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor
+ * Boston, MA  02110-1301 USA.
+ */
+
+#include "livepatch-utils.h"
+
+#include <gio/gdesktopappinfo.h>
+#include <glib.h>
+#include <json-glib/json-glib.h>
+
+#define OS_RELEASE_PATH "/etc/os-release"
+
+GQuark
+livepatch_error_quark(void)
+{
+  static GQuark q = 0;
+
+  if (G_UNLIKELY(!q))
+    q = g_quark_from_static_string("livepatch-error-quark");
+
+  return q;
+}
+
+static GKeyFile *
+parse_osrelease()
+{
+    g_autoptr(GKeyFile) keys;
+    g_autofree gchar *content = NULL;
+    g_autofree gchar *content_with_group = NULL;
+    const gchar *group = "[os-release]\n";
+    g_autoptr(GError) error = NULL;
+
+    if (!g_file_get_contents(OS_RELEASE_PATH, &content, NULL, &error))
+      {
+        g_warning("Failed to read '%s', error: %s",
+                  OS_RELEASE_PATH, error->message);
+        return NULL;
+      }
+
+    content_with_group = g_strdup_printf("%s%s", group, content);
+
+    keys = g_key_file_new();
+    if (!g_key_file_load_from_data(keys, content_with_group, -1,
+                                   G_KEY_FILE_NONE, &error))
+      {
+        g_warning("Failed to parse /etc/os-release: %s", error->message);
+        return NULL;
+      }
+
+    return g_steal_pointer(&keys);
+}
+
+static JsonNode *
+livepatch_get_status(GError **error)
+{
+  g_autofree gchar *standard_output = NULL;
+  g_autoptr(JsonParser) json_parser = NULL;
+
+  if (!g_spawn_command_line_sync("canonical-livepatch status --format=json",
+                                 &standard_output, NULL, NULL, error))
+    return NULL;
+
+  json_parser = json_parser_new();
+  if (!json_parser_load_from_data(json_parser, standard_output, -1, error))
+    return NULL;
+
+  return json_node_copy(json_parser_get_root(json_parser));
+}
+
+static JsonNode *
+livepatch_get_status_node(const gchar *expr, GError **error)
+{
+  g_autoptr(JsonNode) root = NULL;
+
+  root = livepatch_get_status(error);
+  if (root == NULL)
+    return NULL;
+
+  return json_path_query(expr, root, error);
+}
+
+gboolean
+livepatch_has_settings_ui()
+{
+  g_autoptr(GDesktopAppInfo) info = NULL;
+
+  info = g_desktop_app_info_new(LIVEPATCH_DESKTOP_FILE);
+  return info != NULL;
+}
+
+gboolean
+livepatch_is_supported()
+{
+  g_autoptr(GKeyFile) file = NULL;
+  g_autofree gchar *version = NULL;
+  g_autoptr(GError) error = NULL;
+
+  file = parse_osrelease();
+  if (file == NULL)
+    return FALSE;
+
+  version = g_key_file_get_string(file, "os-release", "VERSION", &error);
+  if (version == NULL)
+    {
+      g_warning("Failed to get the version from the file %s: %s",
+                OS_RELEASE_PATH, error->message);
+      return FALSE;
+    }
+
+  return g_strstr_len(version, -1, "LTS") != NULL;
+}
+
+gboolean
+livepatch_is_running()
+{
+  g_autoptr(JsonNode) result_node = NULL;
+  JsonNode *running_node = NULL;
+  JsonArray *result_array;
+
+  result_node = livepatch_get_status_node("$.Status[0].Running", NULL);
+  if (result_node == NULL)
+    return FALSE;
+
+  result_array = json_node_get_array(result_node);
+
+  if (json_array_get_length(result_array) == 0)
+    return FALSE;
+
+  running_node = json_array_get_element(result_array, 0);
+  return json_node_get_boolean(running_node);
+}
+
+gchar *
+livepatch_get_state(GError **error)
+{
+  g_autoptr(JsonNode) result_node = NULL;
+  JsonNode *state_node = NULL;
+  JsonArray *result_array;
+  const gchar *expr = "$.Status[0].Livepatch.State";
+
+  result_node = livepatch_get_status_node(expr, error);
+  if (result_node == NULL)
+    return NULL;
+
+  result_array = json_node_get_array(result_node);
+
+  if (json_array_get_length(result_array) == 0)
+    {
+      g_set_error(error,
+                  LIVEPATCH_ERROR, LIVEPATCH_ERROR_NOMATCH,
+                  "No matches for: %s", expr);
+      return NULL;
+    }
+
+  state_node = json_array_get_element(result_array, 0);
+  return g_strdup(json_node_get_string(state_node));
+}
+
+gchar *
+livepatch_get_check_state(GError **error)
+{
+  g_autoptr(JsonNode) result_node = NULL;
+  JsonNode *state_node = NULL;
+  JsonArray *result_array;
+  const gchar *expr = "$.Status[0].Livepatch.CheckState";
+
+  result_node = livepatch_get_status_node(expr, error);
+  if (result_node == NULL)
+    return NULL;
+
+  result_array = json_node_get_array(result_node);
+
+  if (json_array_get_length(result_array) == 0)
+    {
+      g_set_error(error,
+                  LIVEPATCH_ERROR, LIVEPATCH_ERROR_NOMATCH,
+                  "No matches for: %s", expr);
+      return NULL;
+    }
+
+  state_node = json_array_get_element(result_array, 0);
+  return g_strdup(json_node_get_string(state_node));
+}
+
+gssize
+livepatch_get_num_fixes(GError **error)
+{
+  g_autoptr(JsonNode) node = NULL;
+  JsonArray *array;
+
+  node = livepatch_get_status_node("$.Status[0].Livepatch.Fixes[*]", error);
+  if (node == NULL)
+    return -1;
+
+  array = json_node_get_array(node);
+  return json_array_get_length(array);
+}

=== added file 'src/livepatch-utils.h'
--- src/livepatch-utils.h	1970-01-01 00:00:00 +0000
+++ src/livepatch-utils.h	2019-03-12 15:10:45 +0000
@@ -0,0 +1,38 @@
+/* livepatch-utils.h
+ * Copyright (C) 2019 Andrea Azzarone <andrea.azzarone@canonical.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor
+ * Boston, MA  02110-1301 USA.
+ */
+
+#pragma once
+
+#include <gio/gio.h>
+
+#define LIVEPATCH_ERROR livepatch_error_quark()
+#define LIVEPATCH_DESKTOP_FILE "software-properties-livepatch.desktop"
+
+typedef enum
+{
+  LIVEPATCH_ERROR_NOMATCH
+} LivepatchError;
+
+
+gboolean livepatch_has_settings_ui ();
+gboolean livepatch_is_supported    ();
+gboolean livepatch_is_running      ();
+gchar*   livepatch_get_state       (GError **error);
+gchar*   livepatch_get_check_state (GError **error);
+gssize   livepatch_get_num_fixes   (GError **error);

=== modified file 'src/update-notifier.c'
--- src/update-notifier.c	2019-01-07 14:14:37 +0000
+++ src/update-notifier.c	2019-03-12 15:10:45 +0000
@@ -41,6 +41,7 @@
 #include <gio/gio.h>
 
 #include "update-notifier.h"
+#include "livepatch-tray.h"
 #include "update.h"
 #include "hooks.h"
 #include "uevent.h"
@@ -475,6 +476,11 @@
    trayapplet_create(un->crashreport, un, "apport");
    crashreport_tray_icon_init(un->crashreport);
 
+   /* livepatch icon */
+   un->livepatch = g_new0(TrayApplet, 1);
+   trayapplet_create(un->livepatch, un, "livepatch");
+   livepatch_tray_icon_init(un->livepatch);
+
    return FALSE; // for the tray_destroyed_cb
 }
 

=== modified file 'src/update-notifier.h'
--- src/update-notifier.h	2018-06-27 07:48:12 +0000
+++ src/update-notifier.h	2019-03-12 15:10:45 +0000
@@ -37,6 +37,7 @@
 #define SETTINGS_KEY_END_SYSTEM_UIDS "end-system-uids"
 #define SETTINGS_KEY_AUTO_LAUNCH_INTERVAL "regular-auto-launch-interval"
 #define SETTINGS_KEY_LAST_RELEASE_CHECK "release-check-time"
+#define SETTINGS_KEY_SHOW_LIVEPATCH_ICON "show-livepatch-status-icon"
 
 #define SETTINGS_UM_SCHEMA "com.ubuntu.update-manager"
 #define SETTINGS_UM_KEY_LAST_LAUNCH "launch-time"
@@ -102,6 +103,7 @@
    TrayApplet *update;
    TrayApplet *hook;
    TrayApplet *crashreport;
+   TrayApplet *livepatch;
 
    guint update_finished_timer;
 

